import { r as ref, aX as getImportablePools, aY as getImportableDestroyedPools } from "./index.6d4442b8.js";
const vDevs = ref([]);
const errors = [];
function parseImportVDevData(vDev, poolName, vDevType) {
  try {
    const vDevData = {
      name: vDev.name,
      type: vDevType,
      status: vDev.status,
      guid: vDev.guid,
      stats: vDev.stats,
      disks: vDev.children,
      poolName,
      selectedDisks: []
    };
    vDevs.value.push(vDevData);
  } catch (error) {
    console.error("An error occurred getting vdevs for Importable pools:", error);
  }
}
async function loadImportablePools(importablePools, allDisks, existingPools) {
  try {
    const rawJSON = await getImportablePools();
    const parsedJSON = JSON.parse(rawJSON);
    for (let i = 0; i < parsedJSON.length; i++) {
      parsedJSON[i].groups.data.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "data"));
      parsedJSON[i].groups.cache.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "cache"));
      parsedJSON[i].groups.dedup.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "dedup"));
      parsedJSON[i].groups.log.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "log"));
      parsedJSON[i].groups.spare.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "spare"));
      parsedJSON[i].groups.special.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "special"));
      const poolData = {
        name: parsedJSON[i].name,
        status: parsedJSON[i].status,
        guid: parsedJSON[i].guid,
        properties: parsedJSON[i].properties,
        scan: parsedJSON[i].scan,
        vdevs: vDevs.value,
        isDestroyed: false,
        errors
      };
      importablePools.push(poolData);
      vDevs.value = [];
    }
  } catch (error) {
    console.error("An error occurred getting Importable pools:", error);
  }
}
async function loadImportableDestroyedPools(importablePools, allDisks, existingPools) {
  try {
    const rawJSON = await getImportableDestroyedPools();
    const parsedJSON = JSON.parse(rawJSON);
    for (let i = 0; i < parsedJSON.length; i++) {
      parsedJSON[i].groups.data.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "data"));
      parsedJSON[i].groups.cache.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "cache"));
      parsedJSON[i].groups.dedup.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "dedup"));
      parsedJSON[i].groups.log.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "log"));
      parsedJSON[i].groups.spare.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "spare"));
      parsedJSON[i].groups.special.forEach((vDev) => parseImportVDevData(vDev, parsedJSON[i].name, "special"));
      const poolData = {
        name: parsedJSON[i].name,
        status: parsedJSON[i].status,
        guid: parsedJSON[i].guid,
        properties: parsedJSON[i].properties,
        scan: parsedJSON[i].scan,
        vdevs: vDevs.value,
        isDestroyed: true,
        errors
      };
      importablePools.push(poolData);
      vDevs.value = [];
    }
    console.log("loaded Importable Destroyed Pools:", importablePools);
  } catch (error) {
    console.error("An error occurred getting destroyed importable pools:", error);
  }
}
export {
  loadImportableDestroyedPools as a,
  loadImportablePools as l
};
